@@ -30,7 +30,7 @@
 #' data <- data.frame(
 #'   ID = 1:10,
 #'   PedigreeID = rep(1, 10),
-#'   Sex = c(0, 1, 0, 1, 0, 1, 0, 1, 0, 1),  # 0=female, 1=male
+#'   Sex = c(0, 1, 0, 1, 0, 1, 0, 1, 0, 1), # 0=female, 1=male
 #'   MotherID = c(NA, NA, 1, 1, 3, 3, 5, 5, 7, 7),
 #'   FatherID = c(NA, NA, 2, 2, 4, 4, 6, 6, 8, 8),
 #'   isProband = c(1, rep(0, 9)),
@@ -39,42 +39,44 @@
 #'   Age = c(40, NA, 50, NA, 45, NA, 55, NA, 48, NA),
 #'   Geno = c(1, NA, 1, 0, 1, 0, NA, NA, 1, NA)
 #' )
-#' 
+#'
 #' # Transform data into required format
 #' data <- transformDF(data)
-#' 
+#'
 #' # Set parameters for the chain
 #' seed <- 123
 #' n_iter <- 10
-#' burn_in <- 0.1  # 10% burn-in
+#' burn_in <- 0.1 # 10% burn-in
 #' chain_id <- 1
 #' ncores <- 1
 #' max_age <- 100
-#' 
+#'
 #' # Create baseline data (simplified example)
 #' baseline_data <- matrix(
-#'   c(rep(0.005, max_age), rep(0.008, max_age)),  # Increased baseline risks
+#'   c(rep(0.005, max_age), rep(0.008, max_age)), # Increased baseline risks
 #'   ncol = 2,
 #'   dimnames = list(NULL, c("Male", "Female"))
 #' )
-#' 
+#'
 #' # Set prior distributions with carefully chosen bounds
 #' prior_distributions <- list(
 #'   prior_params = list(
-#'     asymptote = list(g1 = 2, g2 = 3),  # Mode around 0.4
-#'     threshold = list(min = 20, max = 30),  # Narrower range for threshold
-#'     median = list(m1 = 3, m2 = 2),  # Mode around 0.6
-#'     first_quartile = list(q1 = 2, q2 = 3)  # Mode around 0.4
+#'     asymptote = list(g1 = 2, g2 = 3), # Mode around 0.4
+#'     threshold = list(min = 20, max = 30), # Narrower range for threshold
+#'     median = list(m1 = 3, m2 = 2), # Mode around 0.6
+#'     first_quartile = list(q1 = 2, q2 = 3) # Mode around 0.4
 #'   )
 #' )
-#' 
+#'
 #' # Create variance vector for all 8 parameters in sex-specific case
 #' # Using very small variances for initial stability
-#' var <- c(0.005, 0.005,  # asymptotes (smaller variance since between 0-1)
-#'          1, 1,          # thresholds
-#'          1, 1,          # medians
-#'          1, 1)          # first quartiles
-#' 
+#' var <- c(
+#'   0.005, 0.005, # asymptotes (smaller variance since between 0-1)
+#'   1, 1, # thresholds
+#'   1, 1, # medians
+#'   1, 1
+#' ) # first quartiles
+#'
 #' # Run the chain
 #' results <- mhChain(
 #'   seed = seed,
@@ -87,8 +89,8 @@
 #'   max_age = max_age,
 #'   baseline_data = baseline_data,
 #'   prior_distributions = prior_distributions,
-#'   prev = 0.05,  # Increased prevalence
-#'   median_max = FALSE,  # Changed to FALSE for simpler median constraints
+#'   prev = 0.05, # Increased prevalence
+#'   median_max = FALSE, # Changed to FALSE for simpler median constraints
 #'   BaselineNC = TRUE,
 #'   var = var,
 #'   age_imputation = FALSE,
@@ -131,6 +133,25 @@ mhChain <- function(seed, n_iter, burn_in, chain_id, ncores, data, twins, max_ag
   # Initialize variables for sex-specific or non-specific model
   if (sex_specific) {
     # Process baseline risk data for males and females
+    # Check if baseline data matches max_age
+    if (nrow(baseline_data) != max_age) {
+      warning(paste("Baseline data length (", nrow(baseline_data), ") does not match max_age (", max_age, "). Adjusting baseline data to match max_age.", sep=""))
+      
+      # If baseline data is longer than max_age, truncate it
+      if (nrow(baseline_data) > max_age) {
+        baseline_data <- baseline_data[1:max_age, ]
+      } else {
+        # If baseline data is shorter, extend it by repeating the last value
+        last_male <- baseline_data[nrow(baseline_data), "Male"]
+        last_female <- baseline_data[nrow(baseline_data), "Female"]
+        extension <- data.frame(
+          Male = rep(last_male, max_age - nrow(baseline_data)),
+          Female = rep(last_female, max_age - nrow(baseline_data))
+        )
+        baseline_data <- rbind(baseline_data, extension)
+      }
+    }
+    
     baseline_male <- as.numeric(baseline_data[, "Male"])
     baseline_female <- as.numeric(baseline_data[, "Female"])
     baseline_male_cum <- cumsum(baseline_male)
@@ -159,29 +180,56 @@ mhChain <- function(seed, n_iter, burn_in, chain_id, ncores, data, twins, max_ag
       lower_bound <- prior_distributions$prior_params$threshold$min
       upper_bound <- prior_distributions$prior_params$threshold$max
 
-      threshold_male <- ifelse(length(data_male_affected$age) > 0,
-        quantile(data_male_affected$age, 0.1, na.rm = TRUE), NA
-      )
-      threshold_female <- ifelse(length(data_female_affected$age) > 0,
-        quantile(data_female_affected$age, 0.1, na.rm = TRUE), NA
-      )
+      # Add better NA handling for threshold calculations
+      threshold_male <- if(length(data_male_affected$age) > 0 && sum(!is.na(data_male_affected$age)) > 0) {
+        quantile(data_male_affected$age, 0.1, na.rm = TRUE)
+      } else {
+        (lower_bound + upper_bound) / 2  # Use middle of allowed range as default
+      }
+      
+      threshold_female <- if(length(data_female_affected$age) > 0 && sum(!is.na(data_female_affected$age)) > 0) {
+        quantile(data_female_affected$age, 0.1, na.rm = TRUE)
+      } else {
+        (lower_bound + upper_bound) / 2  # Use middle of allowed range as default
+      }
 
       threshold_male <- pmax(pmin(threshold_male, upper_bound, na.rm = TRUE), lower_bound, na.rm = TRUE)
       threshold_female <- pmax(pmin(threshold_female, upper_bound, na.rm = TRUE), lower_bound, na.rm = TRUE)
 
-      median_male <- ifelse(length(data_male_affected$age) > 0,
-        median(data_male_affected$age, na.rm = TRUE), 50
-      )
-      median_female <- ifelse(length(data_female_affected$age) > 0,
-        median(data_female_affected$age, na.rm = TRUE), 50
-      )
+      # Add better NA handling for median calculations
+      median_male <- if(length(data_male_affected$age) > 0 && sum(!is.na(data_male_affected$age)) > 0) {
+        median(data_male_affected$age, na.rm = TRUE)
+      } else {
+        50  # Default value when no data available
+      }
+      
+      median_female <- if(length(data_female_affected$age) > 0 && sum(!is.na(data_female_affected$age)) > 0) {
+        median(data_female_affected$age, na.rm = TRUE)
+      } else {
+        50  # Default value when no data available
+      }
 
-      first_quartile_male <- ifelse(length(data_male_affected$age) > 0,
-        max(min(quantile(data_male_affected$age, probs = 0.25, na.rm = TRUE), median_male - 1), threshold_male + 1), 40
-      )
-      first_quartile_female <- ifelse(length(data_female_affected$age) > 0,
-        max(min(quantile(data_female_affected$age, probs = 0.25, na.rm = TRUE), median_female - 1), threshold_female + 1), 40
-      )
+      # Add better NA handling for first quartile calculations
+      first_quartile_male <- if(length(data_male_affected$age) > 0 && sum(!is.na(data_male_affected$age)) > 0) {
+        q25 <- quantile(data_male_affected$age, probs = 0.25, na.rm = TRUE)
+        max(min(q25, median_male - 1), threshold_male + 1)
+      } else {
+        threshold_male + 0.3 * (median_male - threshold_male)  # Default position between threshold and median
+      }
+      
+      first_quartile_female <- if(length(data_female_affected$age) > 0 && sum(!is.na(data_female_affected$age)) > 0) {
+        q25 <- quantile(data_female_affected$age, probs = 0.25, na.rm = TRUE)
+        max(min(q25, median_female - 1), threshold_female + 1)
+      } else {
+        threshold_female + 0.3 * (median_female - threshold_female)  # Default position between threshold and median
+      }
+      
+      # Ensure parameter relationships are maintained
+      first_quartile_male <- max(first_quartile_male, threshold_male + 1)
+      first_quartile_female <- max(first_quartile_female, threshold_female + 1)
+      
+      median_male <- max(median_male, first_quartile_male + 1)
+      median_female <- max(median_female, first_quartile_female + 1)
 
       asymptote_male <- runif(1, max(baseline_male_cum), 1)
       asymptote_female <- runif(1, max(baseline_female_cum), 1)
@@ -199,6 +247,21 @@ mhChain <- function(seed, n_iter, burn_in, chain_id, ncores, data, twins, max_ag
     }
   } else {
     # Use the baseline data directly as a vector for non-sex-specific
+    # Check if baseline data matches max_age
+    if (length(baseline_data) != max_age) {
+      warning(paste("Baseline data length (", length(baseline_data), ") does not match max_age (", max_age, "). Adjusting baseline data to match max_age.", sep=""))
+      
+      # If baseline data is longer than max_age, truncate it
+      if (length(baseline_data) > max_age) {
+        baseline_data <- baseline_data[1:max_age]
+      } else {
+        # If baseline data is shorter, extend it by repeating the last value
+        last_value <- baseline_data[length(baseline_data)]
+        extension <- rep(last_value, max_age - length(baseline_data))
+        baseline_data <- c(baseline_data, extension)
+      }
+    }
+    
     baseline_cum <- cumsum(baseline_data)
     baseline_df <- data.frame(
       age = 1:length(baseline_data),
@@ -215,19 +278,33 @@ mhChain <- function(seed, n_iter, burn_in, chain_id, ncores, data, twins, max_ag
       lower_bound <- prior_distributions$prior_params$threshold$min
       upper_bound <- prior_distributions$prior_params$threshold$max
 
-      threshold <- ifelse(length(data_affected$age) > 0,
-        quantile(data_affected$age, 0.1, na.rm = TRUE), NA
-      )
+      # Add better NA handling for threshold calculation
+      threshold <- if(length(data_affected$age) > 0 && sum(!is.na(data_affected$age)) > 0) {
+        quantile(data_affected$age, 0.1, na.rm = TRUE)
+      } else {
+        (lower_bound + upper_bound) / 2  # Use middle of allowed range as default
+      }
 
       threshold <- pmax(pmin(threshold, upper_bound, na.rm = TRUE), lower_bound, na.rm = TRUE)
 
-      median_age <- ifelse(length(data_affected$age) > 0,
-        median(data_affected$age, na.rm = TRUE), 50
-      )
+      # Add better NA handling for median calculation
+      median_age <- if(length(data_affected$age) > 0 && sum(!is.na(data_affected$age)) > 0) {
+        median(data_affected$age, na.rm = TRUE)
+      } else {
+        50  # Default value when no data available
+      }
 
-      first_quartile <- ifelse(length(data_affected$age) > 0,
-        min(quantile(data_affected$age, probs = 0.25, na.rm = TRUE), median_age - 1), 40
-      )
+      # Add better NA handling for first quartile calculation
+      first_quartile <- if(length(data_affected$age) > 0 && sum(!is.na(data_affected$age)) > 0) {
+        q25 <- quantile(data_affected$age, probs = 0.25, na.rm = TRUE)
+        min(q25, median_age - 1)
+      } else {
+        threshold + 0.3 * (median_age - threshold)  # Default position between threshold and median
+      }
+      
+      # Ensure parameter relationships are maintained 
+      first_quartile <- max(first_quartile, threshold + 1)
+      median_age <- max(median_age, first_quartile + 1)
 
       asymptote <- runif(1, max(baseline_cum), 1)
 
@@ -290,6 +367,20 @@ mhChain <- function(seed, n_iter, burn_in, chain_id, ncores, data, twins, max_ag
     prior_params <- prior_distributions$prior_params
 
     if (sex_specific) {
+      # Add checks to prevent division by zero
+      if (max_age <= params$threshold_male) {
+        return(-Inf)  # Invalid parameter, reject immediately
+      }
+      if (max_age <= params$threshold_female) {
+        return(-Inf)  # Invalid parameter, reject immediately
+      }
+      if (params$median_male <= params$threshold_male) {
+        return(-Inf)  # Invalid parameter, reject immediately
+      }
+      if (params$median_female <= params$threshold_female) {
+        return(-Inf)  # Invalid parameter, reject immediately
+      }
+      
       scaled_asymptote_male <- params$asymptote_male
       scaled_asymptote_female <- params$asymptote_female
 
